[java-oidc-common] branch main updated: Fix field names and Javadoc

Codeberg noreply at shibboleth.net
Tue Jun 30 10:31:31 UTC 2026


This is an automated email from the git hooks/post-receive script.

codeberg pushed a commit to branch main
in repository java-oidc-common.

View the commit online:
https://codeberg.org/Shibboleth/java-oidc-common/commit/609165574b1d879addc0e037a7607a722fe4bb3d

The following commit(s) were added to refs/heads/main by this push:
     new 60916557 Fix field names and Javadoc
60916557 is described below

commit 609165574b1d879addc0e037a7607a722fe4bb3d
Author: Phil Smart <philip.smart at jisc.ac.uk>
AuthorDate: Tue Jun 30 11:31:17 2026 +0100

    Fix field names and Javadoc
    
     - for logout and state handling
---
 .../oidc/profile/core/OIDCLogoutRequest.java         | 20 ++++++++++----------
 .../messaging/handler/impl/AddStateHandler.java      |  5 ++---
 2 files changed, 12 insertions(+), 13 deletions(-)

diff --git a/oidc-common-profile-impl/src/main/java/net/shibboleth/oidc/profile/messaging/handler/impl/AddStateHandler.java b/oidc-common-profile-impl/src/main/java/net/shibboleth/oidc/profile/messaging/handler/impl/AddStateHandler.java
index 06d54131..c44f0424 100644
--- a/oidc-common-profile-impl/src/main/java/net/shibboleth/oidc/profile/messaging/handler/impl/AddStateHandler.java
+++ b/oidc-common-profile-impl/src/main/java/net/shibboleth/oidc/profile/messaging/handler/impl/AddStateHandler.java
@@ -29,10 +29,9 @@ import net.shibboleth.shared.primitive.LoggerFactory;
  * Add an OAuth 2.0 / OpenID Connect {@code state} value to the authentication request URL and the request object 
  * claims (if present).
  * 
- *  * <p>
+ * <p>
  * The {@code state} parameter helps prevent cross-site request forgery
- * (CSRF) attacks and can be used by clients to maintain request
- * integrity.
+ * (CSRF) attacks and can be used by clients to maintain request and response state.
  * </p>
  * 
  */

diff --git a/oidc-common-profile-api/src/main/java/net/shibboleth/oidc/profile/core/OIDCLogoutRequest.java b/oidc-common-profile-api/src/main/java/net/shibboleth/oidc/profile/core/OIDCLogoutRequest.java
index 08430d60..5a29c1c0 100644
--- a/oidc-common-profile-api/src/main/java/net/shibboleth/oidc/profile/core/OIDCLogoutRequest.java
+++ b/oidc-common-profile-api/src/main/java/net/shibboleth/oidc/profile/core/OIDCLogoutRequest.java
@@ -50,8 +50,8 @@ public class OIDCLogoutRequest {
     /** The ID Token hint. Optional but typically required by OPs. */
     @Nullable private JWT idTokenHint;
     
-    /** The login hint. Optional. */
-    @Nullable private String loginHint;
+    /** The logout hint. Optional. */
+    @Nullable private String logoutHint;
     
     /** The client identifier. Optional.*/
     @Nullable private ClientID clientID;
@@ -113,21 +113,21 @@ public class OIDCLogoutRequest {
     }
     
     /**
      * Get the login_hint parameter.
      * 
      * @return the login hint.
      */
-    @Nullable public String getLoginHint() {
-        return loginHint;
+    @Nullable public String getLogoutHint() {
+        return logoutHint;
     }
     
     /**
      * Set the login_hint parameter.
      * 
      * @param hint The login hint to set.
      */
-    public void setLoginHint(@Nullable final String hint) {
-        loginHint = hint;
+    public void setLogoutHint(@Nullable final String hint) {
+        logoutHint = hint;
     }
     
     /**
@@ -113,21 +113,21 @@ public class OIDCLogoutRequest {
     
     /**
-     * Get the login_hint parameter.
+     * Get the logout_hint parameter.
      * 
@@ -113,21 +113,21 @@ public class OIDCLogoutRequest {
      * 
-     * @return the login hint.
+     * @return the logout hint.
      */
@@ -113,21 +113,21 @@ public class OIDCLogoutRequest {
     
     /**
-     * Set the login_hint parameter.
+     * Set the logout_hint parameter.
      * 
@@ -113,21 +113,21 @@ public class OIDCLogoutRequest {
      * 
-     * @param hint The login hint to set.
+     * @param hint The logout hint to set.
      */
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list